pub type InitialPolicyRuleServerEvent = InitialStateEvent<PolicyRuleServerEventContent>;Available on crate feature
events only.Expand description
An m.policy.rule.server event for creating a room.
Aliased Type
pub struct InitialPolicyRuleServerEvent {
pub content: PolicyRuleServerEventContent,
pub state_key: String,
}Fields
content: PolicyRuleServerEventContentData specific to the event type.
state_key: StringA unique key which defines the overwriting semantics for this piece of room state.
This is often an empty string, but some events send a UserId to show which user the event
affects.
Defaults to the empty string.